@@ -22,6 +22,7 @@
 #include "pool.h"
 #include "poolarch.h"
 #include "util.h"
+#include "evr.h"
 
 
 /*-------------------------------------------------------------------
@@ -36,10 +37,18 @@ solver_is_updating(Solver *solv, Id p)
   Id l, pp;
   if (solv->decisionmap[p] >= 0)
     return 0;	/* old package stayed */
-  r = solv->rules + solv->updaterules + (p - solv->installed->start);
+  r = solv->rules + solv->featurerules + (p - solv->installed->start);
+  if (!r->p)
+    r = solv->rules + solv->updaterules + (p - solv->installed->start);
   FOR_RULELITERALS(l, pp, r)
     if (l > 0 && l != p && solv->decisionmap[l] > 0)
-      return 1;
+      {
+	/* check that this is really an upgrade */
+	Solvable *si = pool->solvables + p;
+	Solvable *s = pool->solvables + l;
+	if (s->name != si->name || pool_evrcmp(pool, s->evr, si->evr, EVRCMP_COMPARE) > 0)
+          return 1;
+      }
   return 0;
 }
 
@@ -399,7 +408,7 @@ solver_add_obsoleted(Solver *solv, Id p, Queue *q)
  * Call solver_add_obsoleted and intersect the result with the
  * elements in Queue q starting at qstart.
  * Assumes that it's the first call if qstart == q->count.
- * May use auxillary map m for the intersection process, all
+ * May use auxiliary map m for the intersection process, all
  * elements of q starting at qstart must have their bit cleared.
  * (This is also true after the function returns.)
  * (See solver_add_obsoleted for limitations of the package p)
