@@ -17,7 +17,7 @@ extern "C" {
 #define STRID_NULL  0
 #define STRID_EMPTY 1
 
-struct _Stringpool
+struct s_Stringpool
 {
   Offset *strings;            /* table of offsets into stringspace, indexed by Id: Id -> Offset */
   int nstrings;               /* number of ids in strings table */
@@ -33,13 +33,15 @@ void stringpool_init_empty(Stringpool *ss);
 void stringpool_clone(Stringpool *ss, Stringpool *from);
 void stringpool_free(Stringpool *ss);
 void stringpool_freehash(Stringpool *ss);
-void stringpool_resize_hash(Stringpool *ss, int numnew);
 
 Id stringpool_str2id(Stringpool *ss, const char *str, int create);
 Id stringpool_strn2id(Stringpool *ss, const char *str, unsigned int len, int create);
 
 void stringpool_shrink(Stringpool *ss);
 
+void stringpool_reserve(Stringpool *ss, int numid, Offset sizeid);
+int stringpool_integrate(Stringpool *ss, int numid, Offset sizeid, Id *idmap);
+
 
 static inline const char *
 stringpool_id2str(Stringpool *ss, Id id)
