@@ -73,7 +73,7 @@ main(int argc, char **argv)
       fprintf(stderr, "archrepo2solv: %s\n", pool_errstr(pool));
       exit(1);
     }
-  tool_write(repo, 0, 0);
+  tool_write(repo, stdout);
   pool_free(pool);
   exit(0);
 }
